@@ -122,22 +122,17 @@ class CodeGen(Visitor[JSVisitorContext]):
         return self.visit(node.body, ctx)
 
     def visit_Import(self, node: ast.Import, ctx: JSVisitorContext):
-        return [f'import {x.asname or x.name} from "{x.name}"' for x in node.names]
+        return [f'import * as {x.asname} from "{x.name}"' if x.asname else f'import "{x.name}"' for x in node.names]
 
     def visit_ImportFrom(self, node: ast.ImportFrom, ctx: JSVisitorContext):
-        multiple = len(node.names) > 1
-        first = node.names[0]
-        return BaseBuilder('import')\
-            .write_if(multiple,
-                      lambda: SurroundBuilder(surround='{}')
-                      .write(BaseBuilder(separator=',').write(BaseBuilder(x.name).write_if(x.asname, BaseBuilder('as').write(x.asname)) for x in node.names)),
-                      or_else=BaseBuilder(f'* as {node.module}') if first.name == '*' else SurroundBuilder(first.name, surround='{}').write_if(first.asname, BaseBuilder('as').write(first.asname))
-                      )\
-            .write('from')\
-            .write(SurroundBuilder(node.module))\
-            .build()
-
-    # def visit_Comment(self, node: ast.PyCF_TYPE_COMMENTS)
+        builder = BaseBuilder(separator=',')
+        for item in node.names:
+            if item.name == '*':
+                builder.write(f'/* Wildcard import not supported: {node.module} */')
+                continue
+            builder.write(f'{item.name} as {item.asname}' if item.asname else item.name)
+        dir = '"../"'
+        return f'import {{{builder.build()}}} from {node.module or dir}'
 
     def visit_ClassDef(self, node: ast.ClassDef, ctx: JSVisitorContext):
         context = ctx.copy(scope=JSScope.CLASS_FIELD)
@@ -153,7 +148,7 @@ class CodeGen(Visitor[JSVisitorContext]):
                    )\
             .write_if(node.bases, lambda: (f'''Object.getOwnPropertyNames({base}.prototype).forEach(name => {{if (name !== 'constructor') {{{node.name}.prototype[name] = {base}.prototype[name];}}}});''' for base in map(lambda base: self.visit(base, ctx), node.bases)))\
             .write(f'{node.name} = new Proxy({node.name}, {{ apply: (clazz, thisValue, args) => new clazz(...args) }});')\
-            .write_if(node.decorator_list, (f'{node.name} = ', reduce(lambda value, element: f'{element}({value})', map(lambda decorator: self.visit(decorator, ctx), node.decorator_list), node.name), ';'))
+            .write_if(node.decorator_list, lambda: (f'{node.name} = ', reduce(lambda value, element: f'{element}({value})', map(lambda decorator: self.visit(decorator, ctx), node.decorator_list), node.name), ';'))
 
         return builder.build()
 
@@ -479,7 +474,7 @@ class CodeGen(Visitor[JSVisitorContext]):
             BaseBuilder(separator='')
             .write_if(node.orelse, '__else: {')
             .write(f'try {{{self.visit(node.body, ctx)}}}')
-            .write_if(node.handlers, "catch(_err) {%s}" % '\n'.join(
+            .write_if(node.handlers, "catch(__err) {%s}" % '\n'.join(
                 BaseBuilder()
                 .write_if(handler.type, lambda: f'if (__err instanceof {self.visit(handler.type, ctx)})')
                 .write(SurroundBuilder(surround='{}', separator=';')
@@ -500,6 +495,9 @@ class CodeGen(Visitor[JSVisitorContext]):
     def visit_Global(self, node: ast.Global, ctx: JSVisitorContext):
         ctx.global_variables.extend(node.names)
         return f'var {",".join(node.names)}'
+    
+    def visit_NoneType(self, null: None, ctx: JSVisitorContext):
+        return 'null'
 
 
 space_regex = re.compile('\s+')
